@@ -83,6 +83,7 @@ class ModelPreset(BaseModel):
         if path.exists():
             with path.open(
                 "r",
+                encoding="utf-8",
             ) as f:
                 data = json.load(f)
             return cls.model_validate(data)
@@ -292,16 +293,14 @@ class Config(BaseModel):
     @classmethod
     def load_from_json(cls, path: Path) -> "Config":
         """从 JSON 文件加载配置"""
-        with path.open(
-            "r",
-        ) as f:
+        with path.open("r", encoding="utf-8") as f:
             data: dict[str, Any] = json.load(f)
         return cls.model_validate(data)
 
     def save_to_toml(self, path: Path):
         """保存配置到 TOML 文件"""
-        with path.open("wb") as f:
-            tomli_w.dump(self.model_dump(), f)
+        with path.open("w", encoding="utf-8") as f:
+            f.write(tomli_w.dumps(self.model_dump()))
 
 
 @dataclass
@@ -474,11 +473,11 @@ class ConfigManager:
             return self.prompts
         self.prompts = Prompts()
         for file in self.private_prompts.glob("*.txt"):
-            async with aiofiles.open(str(file)) as f:
+            async with aiofiles.open(str(file), encoding="utf-8") as f:
                 prompt = await f.read()
             self.prompts.private.append(Prompt(prompt, file.stem))
         for file in self.group_prompts.glob("*.txt"):
-            async with aiofiles.open(str(file)) as f:
+            async with aiofiles.open(str(file), encoding="utf-8") as f:
                 prompt = await f.read()
             self.prompts.group.append(Prompt(prompt, file.stem))
         if not self.prompts.private:
